## no critic: TestingAndDebugging::RequireStrict
package Sah::SchemaR::cpanmodules::list;

our $DATE = '2022-09-25'; # DATE
our $VERSION = '0.003'; # VERSION

our $rschema = do{my$var={base=>"hash",clsets_after_base=>[{allowed_keys_re=>qr(\A(?:([A-Za-z_][A-Za-z0-9_]*)|([A-Za-z_][A-Za-z0-9_]*)?\.([A-Za-z_][A-Za-z0-9_]*(?:\.[A-Za-z_][A-Za-z0-9_]*)*))\z),examples=>[{valid=>1,value=>{}},{valid=>1,value=>{bar=>1,foo=>1}},{summary=>"Invalid property syntax, contains dash",valid=>0,value=>{"foo-bar"=>1}}],keys=>{caption=>["str",{req=>1}],default_lang=>["str",{match=>"\\A[a-z]{2}(_[A-Z]{2})?\\z",req=>1},{}],defhash_v=>["int",{default=>1,req=>1}],description=>["str",{req=>1}],name=>["str",{clset=>[{match=>"\\A\\w+\\z","match.err_level"=>"warn","match.err_msg"=>"should be a word"},{max_len=>32,"max_len.err_level"=>"warn","max_len.err_msg"=>"should be short"}],"clset.op"=>"and",req=>1}],summary=>["str",{clset=>[{max_len=>72,"max_len.err_level"=>"warn","max_len.err_msg"=>"should be short"},{match=>qr(\n),"match.err_level"=>"warn","match.err_msg"=>"should only be a single-line text","match.op"=>"not"}],"clset.op"=>"and",req=>1}],tags=>["array",{of=>["any",{of=>[["str",{req=>1}],["hash",{req=>1}]],req=>1}]}],v=>["float",{default=>1,req=>1}],x=>["any",{},{}]},"keys.restrict"=>0,summary=>"DefHash"},{"keys.restrict"=>1,"merge.add.keys"=>{defhash_v=>["int",{is=>1,req=>1}],entries=>["array*",{of=>["cpanmodules::entry",{req=>1}]}],v=>["int",{is=>1,req=>1}]},req_keys=>["entries"],summary=>"Acme::CPANModules LIST structure"}],clsets_after_type=>['$var->{clsets_after_base}[0]','$var->{clsets_after_base}[1]'],"clsets_after_type.alt.merge.merged"=>[{allowed_keys_re=>'$var->{clsets_after_base}[0]{allowed_keys_re}',examples=>'$var->{clsets_after_base}[0]{examples}',keys=>{caption=>'$var->{clsets_after_base}[0]{keys}{caption}',default_lang=>'$var->{clsets_after_base}[0]{keys}{default_lang}',defhash_v=>["int",{default=>1,is=>1,req=>1}],description=>'$var->{clsets_after_base}[0]{keys}{description}',entries=>'$var->{clsets_after_base}[1]{"merge.add.keys"}{entries}',name=>'$var->{clsets_after_base}[0]{keys}{name}',summary=>'$var->{clsets_after_base}[0]{keys}{summary}',tags=>'$var->{clsets_after_base}[0]{keys}{tags}',v=>["int",{default=>1,is=>1,req=>1}],x=>'$var->{clsets_after_base}[0]{keys}{x}'},"keys.restrict"=>1,req_keys=>'$var->{clsets_after_base}[1]{req_keys}',summary=>"Acme::CPANModules LIST structure"}],resolve_path=>["hash","defhash"],type=>"hash",v=>2};$var->{clsets_after_type}[0]=$var->{clsets_after_base}[0];$var->{clsets_after_type}[1]=$var->{clsets_after_base}[1];$var->{"clsets_after_type.alt.merge.merged"}[0]{allowed_keys_re}=$var->{clsets_after_base}[0]{allowed_keys_re};$var->{"clsets_after_type.alt.merge.merged"}[0]{examples}=$var->{clsets_after_base}[0]{examples};$var->{"clsets_after_type.alt.merge.merged"}[0]{keys}{caption}=$var->{clsets_after_base}[0]{keys}{caption};$var->{"clsets_after_type.alt.merge.merged"}[0]{keys}{default_lang}=$var->{clsets_after_base}[0]{keys}{default_lang};$var->{"clsets_after_type.alt.merge.merged"}[0]{keys}{description}=$var->{clsets_after_base}[0]{keys}{description};$var->{"clsets_after_type.alt.merge.merged"}[0]{keys}{entries}=$var->{clsets_after_base}[1]{"merge.add.keys"}{entries};$var->{"clsets_after_type.alt.merge.merged"}[0]{keys}{name}=$var->{clsets_after_base}[0]{keys}{name};$var->{"clsets_after_type.alt.merge.merged"}[0]{keys}{summary}=$var->{clsets_after_base}[0]{keys}{summary};$var->{"clsets_after_type.alt.merge.merged"}[0]{keys}{tags}=$var->{clsets_after_base}[0]{keys}{tags};$var->{"clsets_after_type.alt.merge.merged"}[0]{keys}{x}=$var->{clsets_after_base}[0]{keys}{x};$var->{"clsets_after_type.alt.merge.merged"}[0]{req_keys}=$var->{clsets_after_base}[1]{req_keys};$var};

1;
# ABSTRACT: Acme::CPANModules LIST structure

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::SchemaR::cpanmodules::list - Acme::CPANModules LIST structure

=head1 VERSION

This document describes version 0.003 of Sah::SchemaR::cpanmodules::list (from Perl distribution Sah-Schemas-CPANModules), released on 2022-09-25.

=head1 DESCRIPTION

This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.

A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-CPANModules>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-CPANModules>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-CPANModules>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
